
:mod:`pyFAI` Package
--------------------

.. automodule:: pyFAI.__init__
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`azimuthalIntegrator` Module
---------------------------------

.. automodule:: pyFAI.azimuthalIntegrator
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`integrate_widget` Module
------------------------------

.. automodule:: pyFAI.integrate_widget
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`geometry` Module
----------------------

.. automodule:: pyFAI.geometry
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`geometryRefinement` Module
--------------------------------

.. automodule:: pyFAI.geometryRefinement
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`detectors` Module
-----------------------

.. automodule:: pyFAI.detectors
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`spline` Module
--------------------

.. automodule:: pyFAI.spline
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`opencl` Module
--------------------

.. automodule:: pyFAI.opencl
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ocl_azim` Module
----------------------

.. automodule:: pyFAI.ocl_azim
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ocl_azim_lut` Module
--------------------------

.. automodule:: pyFAI.ocl_azim_lut
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ocl_azim_csr` Module
--------------------------

.. automodule:: pyFAI.ocl_azim_csr
    :members:
    :undoc-members:
    :show-inheritance:
    
:mod:`ocl_azim_csr_dis` Module
------------------------------

.. automodule:: pyFAI.ocl_azim_csr_dis
    :members:
    :undoc-members:
    :show-inheritance:


:mod:`worker` Module
--------------------

.. automodule:: pyFAI.worker
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`io` Module
----------------

.. automodule:: pyFAI.io
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`calibration` Module
-------------------------

.. automodule:: pyFAI.calibration
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`peak_picker` Module
-------------------------

.. automodule:: pyFAI.peak_picker
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`massif` Module
--------------------

.. automodule:: pyFAI.massif
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`blob_detection` Module
----------------------------

.. automodule:: pyFAI.blob_detection
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`calibrant` Module
-----------------------

.. automodule:: pyFAI.calibrant
    :members:
    :undoc-members:
    :show-inheritance:


:mod:`distortion` Module
------------------------

.. automodule:: pyFAI.distortion
    :members:
    :undoc-members:
    :show-inheritance:


:mod:`units` Module
-------------------

.. automodule:: pyFAI.units
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`utils` Module
-------------------

.. automodule:: pyFAI.utils
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`gui_utils` Module
-----------------------

.. automodule:: pyFAI.gui_utils
    :members:
    :undoc-members:
    :show-inheritance:
    